[gnome-builder] app: rename program mode checks to gnome-builder-cli



commit 4fe369f5aa7c6215cf87740dc873b1b8e3f2b919
Author: Christian Hergert <chergert redhat com>
Date:   Sun Jun 5 14:36:51 2016 -0700

    app: rename program mode checks to gnome-builder-cli

 libide/ide-application-command-line.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/libide/ide-application-command-line.c b/libide/ide-application-command-line.c
index 98958c7..68df5bb 100644
--- a/libide/ide-application-command-line.c
+++ b/libide/ide-application-command-line.c
@@ -257,7 +257,7 @@ ide_application_local_command_line (GApplication   *application,
   if (prgname && g_str_has_prefix (prgname, "lt-"))
     prgname += strlen ("lt-");
 
-  if (g_str_equal (prgname, "ide"))
+  if (g_str_equal (prgname, "gnome-builder-cli"))
     {
       g_assert_cmpstr (entries [0].long_name, ==, "list-commands");
       entries [0].flags = 0;
@@ -277,10 +277,10 @@ ide_application_local_command_line (GApplication   *application,
   ide_application_discover_plugins (self);
 
   /*
    * If we are the "ide" program, then we want to setup ourselves for
    * verb style commands and add a commands group for help.
    */
-  if (g_str_equal (prgname, "ide"))
+  if (g_str_equal (prgname, "gnome-builder-cli"))
     {
       gchar *command_help;
 
@@ -277,10 +277,10 @@ ide_application_local_command_line (GApplication   *application,
 
   /*
-   * If we are the "ide" program, then we want to setup ourselves for
+   * If we are the "cli" program, then we want to setup ourselves for
    * verb style commands and add a commands group for help.
    */


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]